==> hyades.source_1.0.4.1.zip: org/eclipse/hyades/log/ui/internal/views/LogViewer.java <==
/**********************************************************************
 * Copyright (c) 2003 Hyades project.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/

package org.eclipse.hyades.log.ui.internal.views;


import java.util.ArrayList;
import java.util.List;

import org.eclipse.emf.common.util.EList;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.hyades.log.ui.internal.LogUIPlugin;
import org.eclipse.hyades.log.ui.internal.LogUIPluginImages;
import org.eclipse.hyades.log.ui.internal.util.ColumnsDialog;
import org.eclipse.hyades.log.ui.internal.util.SortDialog;
import org.eclipse.hyades.models.hierarchy.*;
import org.eclipse.hyades.trace.ui.*;
import org.eclipse.jface.action.Action;
import org.eclipse.jface.action.IToolBarManager;
import org.eclipse.jface.viewers.StructuredSelection;
import org.eclipse.jface.window.Window;
import org.eclipse.ui.part.IPage;

public class LogViewer extends TraceViewer {
	protected final String _title =
		LogUIPlugin.getResourceString("STR_WAS_VIEW_TITLE");
	private LogPage logPage;

	public LogViewer() {
		super();
	}
	/**
	 * Creates a log viewer page
	 * Creation date: (08/01/2000 4:17:37 PM)
	 * @return TraceViewerPage
	 */
	public TraceViewerPage createPage(EObject mofObject) {
		logPage = new LogPage(mofObject, this);
		return logPage;
	}

	public void handleProfileEvent(ProfileEvent event) {

		if (((event.getType() == ProfileEvent.REFRESH_VIEWS)
			|| (event.getType() == ProfileEvent.UPDATE_MODEL)
			|| (event.getType() == ProfileEvent.UPDATE_DELTA_TIME))			
			&& (event.getSource() instanceof EObject)) {
				
			if(!fProcessRefreshEvents)
			{		
				//ignore the events and keep track that the page need to be updated			
			   fRefreshView = true;		   
				return;
			}
			
			refreshPage(getObjectToView((EObject) event.getSource()));
		}
	}

	/**	 
	 * Disposes every cached page and 
	 * cleans up the hashtable that caches the log (trace) viewer pages
	 * @see TraceViewer#dispose
	 * @see IWorkbenchPart#dispose
	 */
	public void dispose() {
		super.dispose();
	}
	/**
	 * Creates actions for opening the filter and sort dialogs
	 * and adds them to the toolbar
	 * Creation date: (1/11/2001 2:54:24 PM)
	 */
	public void makeActions() {
		if (isInitializedMenu()) {
			return; //create the toolbar only once
		}

		initializedMenu(true);

		String STR_SORT = LogUIPlugin.getResourceBundle().getString("STR_SORT");
		Action sort = new Action(STR_SORT) {
			public void run() {
				SortDialog dialog =
					new SortDialog(
						getViewSite().getShell(),
						LogUIPlugin.getResourceString(
							"STR_ST_SORT_COL_SETTINGS"),
						null);
				dialog.open();
				if (dialog.getReturnCode() == Window.OK) {
					final IPage page = getCurrentPage();

					if (page != null && page instanceof LogPage) {

						org
							.eclipse
							.swt
							.custom
							.BusyIndicator
							.showWhile(null, new Runnable() {
							public void run() {

								((LogPage) page).getView().update();
							}
						});
					}
				}

			}
		};
		sort.setText(STR_SORT);
		LogUIPluginImages.setImageDescriptors(
			sort,
			LogUIPluginImages.T_LCL,
			LogUIPluginImages.IMG_SORT);
		sort.setDescription(STR_SORT);
		sort.setToolTipText(STR_SORT);

		String STR_FILTER =
			LogUIPlugin.getResourceBundle().getString("STR_FILTER");
		Action filter = new Action(STR_FILTER) {
			public void run() {
				ColumnsDialog dialog =
					new ColumnsDialog(
						getViewSite().getShell(),
						LogUIPlugin.getResourceString("STR_ST_COL_SETTINGS"),
						null);
				dialog.open();
			}
		};
		filter.setText(STR_FILTER);
		LogUIPluginImages.setImageDescriptors(
			filter,
			LogUIPluginImages.T_LCL,
			LogUIPluginImages.IMG_FILTER);
		filter.setDescription(STR_FILTER);
		filter.setToolTipText(STR_FILTER);

		IToolBarManager tbm = getViewSite().getActionBars().getToolBarManager();

		tbm.add(sort);
		tbm.add(filter);

		// requires update because the toolbar control has been created by this point,
		// but the toolbar manager does not update it automatically once it has been created
		getViewSite().getActionBars().updateActionBars();
	}
	/**
	 * @see WorkbenchPart#setFocus 
	 * Creation date: (10/5/2001 11:42:53 AM)
	 */
	public void setFocus() {

		if (getCurrentPage() != null)
			getCurrentPage().setFocus();
	}

	/**
	 * @return true if the object can be viewed using this type of view 
	 * 
	 */
	public boolean isValidObject(Object mofObject) {
		if (mofObject == null)
			return false;

		if (mofObject instanceof TRCAgent
			&& ((TRCAgent) mofObject).getType().equals(
				HyadesConstants.LOG_AGENT_TYPE)) {
			return true;
		}

		if (mofObject instanceof TRCProcessProxy) {
			return hasProcessLogAgents((TRCProcessProxy)mofObject);
		}
		
		if(mofObject instanceof TRCNode){
			return hasNodeLogAgents((TRCNode)mofObject);
		}
		
		if(mofObject instanceof TRCMonitor){
			return hasMonitorLogAgents((TRCMonitor)mofObject);
		}
		

		return true;
	}

	/**
	 * @return the object that should be viewed
	 * For example, if the process node is selected, the view should display
	 * the profiling data if trace collects profiling data
	 * Returns the agent if there is only one log agent
	 * 
	 */

	public EObject getObjectToView(EObject selObject) {

		if (selObject == null)
			return selObject;

		List list =null;
		
		if(selObject instanceof TRCMonitor){

			list = getLogObjectInMonitor((TRCMonitor)selObject);
			
		}else if(selObject instanceof TRCNode){
			
			list = getLogObjectInNode((TRCNode)selObject);
		
		}else if (selObject instanceof TRCProcessProxy) {

			list = getLogAgentInProcess((TRCProcessProxy)selObject); 
			
		}
		if(list!=null && list.size()==1){
			return (EObject)list.get(0);
		}
		return selObject;
	}

	private List getLogObjectInMonitor(EObject selObject){

		EList nodes = ((TRCMonitor)selObject).getNodes();
		TRCNode node = null;

		int size = nodes.size();
		int nrOfNodes = 0;
		List object_list = new ArrayList();
		List list;		

		for(int i=0; i < size && nrOfNodes < 2;i++){		
			node = (TRCNode)nodes.get(i);
			if(node==null){
				continue;
			}else{	
				
				list = getLogObjectInNode(node); 
				if(list.size()>=1){
					nrOfNodes++;					
					object_list.add(node);
				}
			}
			
		}
		
		if(object_list.size()==1){
			list = getLogObjectInNode((TRCNode)object_list.get(0));
			if(list.size()==1){
				object_list.clear();
				object_list.add(list.get(0));
			}
		}
		
		return object_list;
	}
	
	private List getLogObjectInNode(EObject selObject){

		EList processes = ((TRCNode)selObject).getProcessProxies();
		TRCProcessProxy process = null;
		int nrOfProcesses = 0;
		int size = processes.size();
		List list;
		List object_list = new ArrayList();

		for(int i=0; i < size && nrOfProcesses < 2;i++){		
			process = (TRCProcessProxy)processes.get(i);
			if(process!=null){
				list = getLogAgentInProcess(process);
				if(list.size()>=1){
					nrOfProcesses++;
					object_list.add(process);
				}
			}else{
				continue;								
			}
		}
		
		if(object_list.size()==1){
			list = getLogAgentInProcess((TRCProcessProxy)object_list.get(0));
			if(list.size()==1){
				object_list.clear();
				object_list.add(list.get(0));
			}
			
		}
		return object_list;
	}
	
	private List getLogAgentInProcess(EObject selObject){

		int nrOfAgents = 0;
		EList agents = ((TRCProcessProxy)selObject).getAgentProxies();
		int size = agents.size();
		TRCAgentProxy a = null;
		List list =  new ArrayList();
		
		for (int idx = 0; idx < size && nrOfAgents < 2; idx++) {
			a = (TRCAgentProxy) agents.get(idx);
			if (a == null || a.eIsProxy())
				continue;
			if (a.getType().equals(HyadesConstants.LOG_AGENT_TYPE)) {
				nrOfAgents++;
				list.add(a);
			}
		}
		
		return list;
	
	}
	
	
	private boolean hasMonitorLogAgents(TRCMonitor monitor){
		
		EList nodes = monitor.getNodes();
		TRCNode node = null;
		int size = nodes.size();
		boolean ret = false;		

		for(int i=0; i < size  && !ret;i++){		
			node = (TRCNode)nodes.get(i);
			if(node!=null){
				ret = hasNodeLogAgents(node);
			}
			
		}
		
		return ret;
		
	}
	
	private boolean hasNodeLogAgents(TRCNode node){

		EList processes = node.getProcessProxies();
		TRCProcessProxy process = null;
		boolean ret = false;
		
		int size = processes.size();

		for(int i=0; i < size && !ret;i++){
			process = (TRCProcessProxy)processes.get(i);
			if(process!=null){
				ret = hasProcessLogAgents(process);
			}
		}
		
		return ret;
		
	}
	
	private boolean hasProcessLogAgents(TRCProcessProxy process){
		
		EList agents = process.getAgentProxies();
		int size = agents.size();
		TRCAgentProxy agent = null;		
		
		for (int idx = 0; idx < size; idx++) {
			agent = (TRCAgentProxy) agents.get(idx);
			if (agent == null || agent.eIsProxy())
				continue;
			if (agent.getType().equals(HyadesConstants.LOG_AGENT_TYPE)) {
				return true;
			}
		}
		
		return false;
	}
	
	
	/**
	 * Initial view title 
	 */
	public String getViewTitle() {
		return _title;
	}

	public void setRecordSelection(EObject record, EObject treeSel) {
		if (getPage(treeSel) == null)
			return;

		LogViewerUI ui = ((LogPage) getPage(treeSel)).getView();
		if (ui != null && ui.getViewer() != null) {
			ui.getViewer().setSelection(new StructuredSelection(record), true);
		}
	}

	protected void setViewTitle(Object selection) {
		if (selection != null) {
			/*if (selection instanceof EObject)
				selection = getObjectToView((EObject) selection);*/

			if (selection instanceof TRCAgentProxy) {
				TRCAgentProxy a = (TRCAgentProxy) selection;

				String status = HyadesUtil.getAgentLabel(a);

				setTitle(
					(new StringBuffer())
						.append(_title)
						.append(" - ")
						.append(a.getName())
						.append(" ")
						.append(a.getProcessProxy().getName())
						.toString());
				return;

			}
		}
		setTitle(getViewTitle());
	}

}

==> hyades.source_1.1.0_20030930_2244.zip: org/eclipse/hyades/log/ui/internal/views/LogViewer.java <==
/**********************************************************************
 * Copyright (c) 2003 Hyades project.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/

package org.eclipse.hyades.log.ui.internal.views;


import java.util.ArrayList;
import java.util.List;

import org.eclipse.emf.common.util.EList;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.hyades.log.ui.internal.LogUIPlugin;
import org.eclipse.hyades.log.ui.internal.LogUIPluginImages;
import org.eclipse.hyades.log.ui.internal.util.ColumnsDialog;
import org.eclipse.hyades.log.ui.internal.util.FiltersDialog;
import org.eclipse.hyades.log.ui.internal.util.SortDialog;
import org.eclipse.hyades.models.hierarchy.TRCAgent;
import org.eclipse.hyades.models.hierarchy.TRCAgentProxy;
import org.eclipse.hyades.models.hierarchy.TRCMonitor;
import org.eclipse.hyades.models.hierarchy.TRCNode;
import org.eclipse.hyades.models.hierarchy.TRCProcessProxy;
import org.eclipse.hyades.trace.ui.HyadesConstants;
import org.eclipse.hyades.trace.ui.HyadesUtil;
import org.eclipse.hyades.trace.ui.ProfileEvent;
import org.eclipse.hyades.trace.ui.TraceViewer;
import org.eclipse.hyades.trace.ui.TraceViewerPage;
import org.eclipse.jface.action.Action;
import org.eclipse.jface.action.IToolBarManager;
import org.eclipse.jface.viewers.StructuredSelection;
import org.eclipse.jface.window.Window;
import org.eclipse.ui.part.IPage;

public class LogViewer extends TraceViewer {
	protected final String _title =
		LogUIPlugin.getResourceString("STR_WAS_VIEW_TITLE");
	private LogPage logPage;

	public LogViewer() {
		super();
	}
	/**
	 * Creates a log viewer page
	 * Creation date: (08/01/2000 4:17:37 PM)
	 * @return TraceViewerPage
	 */
	public TraceViewerPage createPage(EObject mofObject) {
		logPage = new LogPage(mofObject, this);
		return logPage;
	}

	public void handleProfileEvent(ProfileEvent event) {

		if (((event.getType() == ProfileEvent.REFRESH_VIEWS)
			|| (event.getType() == ProfileEvent.UPDATE_MODEL)
			|| (event.getType() == ProfileEvent.UPDATE_DELTA_TIME))			
			&& (event.getSource() instanceof EObject)) {
				
			if(!fProcessRefreshEvents)
			{		
				//ignore the events and keep track that the page need to be updated			
			   fRefreshView = true;		   
				return;
			}
			
			refreshPage(getObjectToView((EObject) event.getSource()));
		}
	}

	/**	 
	 * Disposes every cached page and 
	 * cleans up the hashtable that caches the log (trace) viewer pages
	 * @see TraceViewer#dispose
	 * @see IWorkbenchPart#dispose
	 */
	public void dispose() {
		super.dispose();
	}
	/**
	 * Creates actions for opening the filter and sort dialogs
	 * and adds them to the toolbar
	 * Creation date: (1/11/2001 2:54:24 PM)
	 */
	public void makeActions() {
		if (isInitializedMenu()) {
			return; //create the toolbar only once
		}

		initializedMenu(true);

		String STR_SORT = LogUIPlugin.getResourceBundle().getString("STR_SORT");
		Action sort = new Action(STR_SORT) {
			public void run() {
				SortDialog dialog =
					new SortDialog(
						getViewSite().getShell(),
						LogUIPlugin.getResourceString(
							"STR_ST_SORT_COL_SETTINGS"),
						null);
				dialog.open();
				if (dialog.getReturnCode() == Window.OK) {
					final IPage page = getCurrentPage();

					if (page != null && page instanceof LogPage) {

						org
							.eclipse
							.swt
							.custom
							.BusyIndicator
							.showWhile(null, new Runnable() {
							public void run() {

								((LogPage) page).getView().update();
							}
						});
					}
				}

			}
		};
		sort.setText(STR_SORT);
		LogUIPluginImages.setImageDescriptors(
			sort,
			LogUIPluginImages.T_LCL,
			LogUIPluginImages.IMG_SORT);
		sort.setDescription(STR_SORT);
		sort.setToolTipText(STR_SORT);

		String STR_FILTER =
			LogUIPlugin.getResourceBundle().getString("STR_FILTER");
		Action filter = new Action(STR_FILTER) {
			public void run() {
				ColumnsDialog dialog =
					new ColumnsDialog(
						getViewSite().getShell(),
						LogUIPlugin.getResourceString("STR_ST_COL_SETTINGS"),
						null);
				dialog.open();
			}
		};
		filter.setText(STR_FILTER);
		LogUIPluginImages.setImageDescriptors(
			filter,
			LogUIPluginImages.T_LCL,
			LogUIPluginImages.IMG_FILTER);
		filter.setDescription(STR_FILTER);
		filter.setToolTipText(STR_FILTER);

		String STR_ADV_FILTER =
			LogUIPlugin.getResourceBundle().getString("STR_ADV_FILTER");
		Action advfilter = new Action(STR_ADV_FILTER) {
			public void run() {
				FiltersDialog dialog =
					new FiltersDialog(
						getViewSite().getShell(),
						LogUIPlugin.getResourceString("STR_ST_FILTER_SETTINGS"),
						null);
				dialog.open();
			}
		};
		advfilter.setText(STR_ADV_FILTER);
		LogUIPluginImages.setImageDescriptors(
			advfilter,
			LogUIPluginImages.T_LCL,
			LogUIPluginImages.IMG_ADV_FILTER);
		advfilter.setDescription(STR_ADV_FILTER);
		advfilter.setToolTipText(STR_ADV_FILTER);



		IToolBarManager tbm = getViewSite().getActionBars().getToolBarManager();

		tbm.add(sort);
		tbm.add(filter);
		tbm.add(advfilter);

		// requires update because the toolbar control has been created by this point,
		// but the toolbar manager does not update it automatically once it has been created
		getViewSite().getActionBars().updateActionBars();
	}
	/**
	 * @see WorkbenchPart#setFocus 
	 * Creation date: (10/5/2001 11:42:53 AM)
	 */
	public void setFocus() {

		if (getCurrentPage() != null)
			getCurrentPage().setFocus();
	}

	/**
	 * @return true if the object can be viewed using this type of view 
	 * 
	 */
	public boolean isValidObject(Object mofObject) {
		if (mofObject == null)
			return false;

		if (mofObject instanceof TRCAgent
			&& ((TRCAgent) mofObject).getType().equals(
				HyadesConstants.LOG_AGENT_TYPE)) {
			return true;
		}

		if (mofObject instanceof TRCProcessProxy) {
			return hasProcessLogAgents((TRCProcessProxy)mofObject);
		}
		
		if(mofObject instanceof TRCNode){
			return hasNodeLogAgents((TRCNode)mofObject);
		}
		
		if(mofObject instanceof TRCMonitor){
			return hasMonitorLogAgents((TRCMonitor)mofObject);
		}
		

		return true;
	}

	/**
	 * @return the object that should be viewed
	 * For example, if the process node is selected, the view should display
	 * the profiling data if trace collects profiling data
	 * Returns the agent if there is only one log agent
	 * 
	 */

	public EObject getObjectToView(EObject selObject) {

		if (selObject == null)
			return selObject;

		List list =null;
		
		if(selObject instanceof TRCMonitor){

            return selObject; //selection model must be at the monitor level
			//list = getLogObjectInMonitor((TRCMonitor)selObject);
			
		}else if(selObject instanceof TRCNode){
			
			return selObject;//selection model must be at the monitor level
			//list = getLogObjectInNode((TRCNode)selObject);
		
		}else if (selObject instanceof TRCProcessProxy) {

			list = getLogAgentInProcess((TRCProcessProxy)selObject); 
			
		}
		if(list!=null && list.size()==1){
			return (EObject)list.get(0);
		}
		return selObject;
	}

	private List getLogObjectInMonitor(EObject selObject){

		EList nodes = ((TRCMonitor)selObject).getNodes();
		TRCNode node = null;

		int size = nodes.size();
		int nrOfNodes = 0;
		List object_list = new ArrayList();
		List list;		

		for(int i=0; i < size && nrOfNodes < 2;i++){		
			node = (TRCNode)nodes.get(i);
			if(node==null){
				continue;
			}else{	
				
				list = getLogObjectInNode(node); 
				if(list.size()>=1){
					nrOfNodes++;					
					object_list.add(node);
				}
			}
			
		}
		
		if(object_list.size()==1){
			list = getLogObjectInNode((TRCNode)object_list.get(0));
			if(list.size()==1){
				object_list.clear();
				object_list.add(list.get(0));
			}
		}
		
		return object_list;
	}
	
	private List getLogObjectInNode(EObject selObject){

		EList processes = ((TRCNode)selObject).getProcessProxies();
		TRCProcessProxy process = null;
		int nrOfProcesses = 0;
		int size = processes.size();
		List list;
		List object_list = new ArrayList();

		for(int i=0; i < size && nrOfProcesses < 2;i++){		
			process = (TRCProcessProxy)processes.get(i);
			if(process!=null){
				list = getLogAgentInProcess(process);
				if(list.size()>=1){
					nrOfProcesses++;
					object_list.add(process);
				}
			}else{
				continue;								
			}
		}
		
		if(object_list.size()==1){
			list = getLogAgentInProcess((TRCProcessProxy)object_list.get(0));
			if(list.size()==1){
				object_list.clear();
				object_list.add(list.get(0));
			}
			
		}
		return object_list;
	}
	
	private List getLogAgentInProcess(EObject selObject){

		int nrOfAgents = 0;
		EList agents = ((TRCProcessProxy)selObject).getAgentProxies();
		int size = agents.size();
		TRCAgentProxy a = null;
		List list =  new ArrayList();
		
		for (int idx = 0; idx < size && nrOfAgents < 2; idx++) {
			a = (TRCAgentProxy) agents.get(idx);
			if (a == null || a.eIsProxy())
				continue;
			if (a.getType().equals(HyadesConstants.LOG_AGENT_TYPE)) {
				nrOfAgents++;
				list.add(a);
			}
		}
		
		return list;
	
	}
	
	
	private boolean hasMonitorLogAgents(TRCMonitor monitor){
		
		EList nodes = monitor.getNodes();
		TRCNode node = null;
		int size = nodes.size();
		boolean ret = false;		

		for(int i=0; i < size  && !ret;i++){		
			node = (TRCNode)nodes.get(i);
			if(node!=null){
				ret = hasNodeLogAgents(node);
			}
			
		}
		
		return ret;
		
	}
	
	private boolean hasNodeLogAgents(TRCNode node){

		EList processes = node.getProcessProxies();
		TRCProcessProxy process = null;
		boolean ret = false;
		
		int size = processes.size();

		for(int i=0; i < size && !ret;i++){
			process = (TRCProcessProxy)processes.get(i);
			if(process!=null){
				ret = hasProcessLogAgents(process);
			}
		}
		
		return ret;
		
	}
	
	private boolean hasProcessLogAgents(TRCProcessProxy process){
		
		EList agents = process.getAgentProxies();
		int size = agents.size();
		TRCAgentProxy agent = null;		
		
		for (int idx = 0; idx < size; idx++) {
			agent = (TRCAgentProxy) agents.get(idx);
			if (agent == null || agent.eIsProxy())
				continue;
			if (agent.getType().equals(HyadesConstants.LOG_AGENT_TYPE)) {
				return true;
			}
		}
		
		return false;
	}
	
	
	/**
	 * Initial view title 
	 */
	public String getViewTitle() {
		return _title;
	}

	public void setRecordSelection(EObject record, EObject treeSel) {
		if (getPage(treeSel) == null)
			return;

		LogViewerUI ui = ((LogPage) getPage(treeSel)).getView();
		if (ui != null && ui.getViewer() != null) {
			ui.getViewer().setSelection(new StructuredSelection(record), true);
		}
	}

	protected void setViewTitle(Object selection) {
		if (selection != null) {
			/*if (selection instanceof EObject)
				selection = getObjectToView((EObject) selection);*/

			if (selection instanceof TRCAgentProxy) {
				TRCAgentProxy a = (TRCAgentProxy) selection;

				String status = HyadesUtil.getAgentLabel(a);

				setTitle(
					(new StringBuffer())
						.append(_title)
						.append(" - ")
						.append(a.getName())
						.append(" ")
						.append(a.getProcessProxy().getName())
						.toString());
				return;

			}
		}
		setTitle(getViewTitle());
	}

}
